#
# spec file for package cf
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Define just "test" as a package in _multibuild file to distinguish test
# instructions here
%if "" == ""
%define _test 0
%define name_ext %nil
%else
%define _test 1
%define name_ext -test
%endif

%global provider        code.cloudfoundry
%global provider_tld    org
%global project         ""
%global repo            cli
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

%define         short_name cf-cli
Name:           %{short_name}%{?name_ext}
Version:        6.51.0
Release:        2.20
Summary:        Cloud Foundry command line client
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/cloudfoundry/cli
Source:         v%{version}.tar.gz
Source1:        README
Source2:        cf-cli-rpmlintrc
%if 0%{?_test}
BuildRequires:  %{short_name} = %{version}
%else
BuildRequires:  go1.13
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%{go_nostrip}
%{go_provides}
%endif

%description
This is the official command line client for Cloud Foundry.

%prep
%if 0%{?_test}
# workaround to prevent post/install failing assuming this file for whatever
# reason
touch %{_sourcedir}/%{short_name}
%else
%setup -q -c -n %{name}-%{version}
mv */* ./
cp %{SOURCE1} ./
%endif

%build
%if 0%{?_test}
cf --help
%else
# show correct version instead of 0.0.0
grep -rl "0.0.0-unknown-version" ./ | xargs sed -i 's/0.0.0-unknown-version/%{version}/g'
%goprep %{import_path}
%gobuild

%check
echo 'Test if cf can be executed'
../go/bin/cli --version
%endif

%install
%if 0%{?_test}
# disable debug packages in package test to prevent error about missing files
%define debug_package %{nil}
%else
mkdir -p %{buildroot}/%{_bindir}
cp ../go/bin/cli %{buildroot}/%{_bindir}/cf
install -m 755 -d %{buildroot}/%{_sysconfdir}/bash_completion.d
cp ci/installers/completion/cf %{buildroot}/%{_sysconfdir}/bash_completion.d/cf.sh
%endif

%files
%if 0%{?_test}
%else
%defattr(-,root,root,-)
%{_bindir}/cf
%config %{_sysconfdir}/bash_completion.d/cf.sh
%doc LICENSE NOTICE README
%endif

%changelog
* Tue Jan 12 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix install on aarch64
* Wed Apr  8 2020 thardeck@suse.com
- update to version 6.51.0
  [#]## Bug Fixes
  - Increased resiliency to log cache streaming log loss on foundations with multiple log cache doppler nodes [story](https://www.pivotaltracker.com/story/show/171759407)
  - cf logs --recent lost logs if there are more than 4 MB of logs [story](https://www.pivotaltracker.com/story/show/171676674)
  - cf logs now properly retries getting logs on connection failure to the logging API [story](https://www.pivotaltracker.com/story/show/171530294)
  - Requests to Log Cache were not logged in the same format as other HTTP requests in the cf CLI [story](https://www.pivotaltracker.com/story/show/171528424)
* Wed Mar  4 2020 thardeck@suse.com
- update to version 6.50.0
  - The cf CLI will now only negotiate TLS 1.2 connections. The cipher suites are restricted to those recommended by the Mozilla SSL Configuration Generator story
  - The cf CLI now streams logs from Log Cache instead of the soon to be deprecated Traffic Controller, Log Cache provides more stability to larger foundations, as well as reduced IAAS costs story
  - The cf CLI will now properly warn users when using an incompatible CC API version (anything less than cf-deployment 7.0.0) story
* Mon Jan 13 2020 thardeck@suse.com
- update to version 6.49.0
  [#]## Bug Fixes
  - `--hostname` command line option now overrides random-route specified in manifest. [Story](https://www.pivotaltracker.com/story/show/170171569)
  - Commands that modify buildpacks (`update-buildpack`, `rename-buildpack`, `delete-buildpack`) now single-quote the name of the buildpack and stack in the error message when the buildpack is not found.
* Thu Dec  5 2019 thardeck@suse.com
- update to version 6.48.0
  [#]## Enhancements
  - Improve Behavior of --random-route Flag. Increased the size of the namespace used for generating random route names from eight thousand to over five million. This reduces the odds of a name conflict.
  [#]## Bug Fixes
  - Fixes a bug where `cf delete app -r` did not delete routes if you had more than 50 routes associated with the app. [Story](https://www.pivotaltracker.com/story/show/165714515)
  - Fixes a bug where `cf create-buildpack` would return a misleading error when the buildpack name had invalid characters. [Story](https://www.pivotaltracker.com/story/show/168183422)
* Thu Nov 28 2019 thardeck@suse.com
- update to version 6.47.2
  [#]# Fixes
  - Built with Golang 1.12.12 to address security vulnerabilities and other bugs. See the Golang release summaries for details.
* Mon Oct 21 2019 thardeck@suse.com
- update to version 6.47.1
  [#]# Bugs
  - Fixes regression for cf login
  - create-buildpack will now retry if attempting to create a large buildpack and the fresh token is about to expire story
  - now when you push an application with a buildpack, and if you delete the buildpack, and then subsequently push the same app with multiple buildpacks, push should stage your app story
  [#]# Enhancements
  - Since usernames are not unique, users with the same name can exist in different external identity providers. This release supports a new flag on login: --origin which allow users to disambiguate the user and identity provider they want to log in to. story
  - Adds a deprecation warning to cf login and cf auth for custom clients. In CLI V7, we are encouraging users to adopt the client credential workflow because it is more secure (secrets are not written to the config). story and story
  - If you are not logged in and attempt to run commands, now a slightly more verbose output appears to prompt the user to run either 'cf login' or 'cf login --sso' to log in.. story
  - the CF_DIAL_TIMEOUT default has been updated from 5 to 6 seconds to avoid race conditions story
* Mon Aug 26 2019 thardeck@suse.com
- update to version 6.46.1
  [#]## Bugs
  - Fixes an issue where `update-user-provided-service` can unset existing
  credentials associated with a service even when the `-p` flags is not specified [story](https://www.pivotaltracker.com/story/show/167220606)
* Wed Jul 10 2019 thardeck@suse.com
- update to version 6.46.0
  [#]## Bugs
  - Fixes `cf push` remove spin lock in PollStart(). This reduces the CPU time when waiting for apps to start. Also affects  `cf start`, `cf restart` and `cf restage` [story](https://www.pivotaltracker.com/story/show/165861946)
  - Fixes a documentation url in output [story](https://www.pivotaltracker.com/story/show/166249597)
  - Fixes an issue whereby if you are logged in as a client, the user name was not printed in the output [story](https://www.pivotaltracker.com/story/show/166848659)
  - Targeting a space for `cf copy-source` is no longer case sensitive [story](https://www.pivotaltracker.com/story/show/166110649)
* Tue Jun  4 2019 thardeck@suse.com
- update to version 6.45.0
  [#]## Bug Fixes
  - Fixes a regression for `v3-push` whilst viewing logs when authenticated as a client. Now you are able to see logs if you are logged in as a client and you attempt to view logs (cf logs for example).
* Wed May  8 2019 thardeck@suse.com
- update to version 6.44.1
* Wed May  8 2019 thardeck@suse.com
- update to version 6.44.0
  [#]## Enhancements
  - A new flag `--no-plans` added to `cf marketplace` to view the table without the `plans` column [story](https://www.pivotaltracker.com/story/show/164981967)
  [#]## Minor Enhancements
  - `cf help ` now displays a more prominent `TIP` so that users can discover `cf help -a`
  - Roles for the `set-org-role` and `set-space-role` commands are case insensitive [story](https://www.pivotaltracker.com/story/show/163495325)
  - Piping a multi-line file to `cf login` now works as expected [story](https://www.pivotaltracker.com/story/show/164256604)
  - Updated the help text for `cf delete-orphaned-routes` to clarify that the command is spaced-scoped [story](https://www.pivotaltracker.com/story/show/164657893)
  [#]## Bug Fixes
  - Fixes a bug for `cf update-buildpack` for assigning stacks [story](https://www.pivotaltracker.com/story/show/164998479)
  - Fixes an issue with `cf-bind-route-service` whereby if a user does not have a `org` or `space` targeted, instead of returning a useful error, the CLI would attempt to `GET` the `private_domains` endpoint [story](https://www.pivotaltracker.com/story/show/164157632)
  - `v3-apply-manifest` now works for defining environment variables in a multi-app manifest [story](https://www.pivotaltracker.com/story/show/164998227)
  - Now the CLI checks the expiration time of an access token and refreshes it automatically before making a call the CF API [story](https://github.com/cloudfoundry/cli/pull/1594)
* Wed May  8 2019 thardeck@suse.com
- update to version 6.43.0
  [#]## Enhancements
  - `cf curl` supports a new `--fail` flag (primarily for scripting purposes) which returns exit code `22` for server errors [story](https://www.pivotaltracker.com/story/show/130060949)
  - Improves `cf delete-orphaned-routes` such that it uses a different endpoint, reducing the chance of a race condition when two users are simultaneously deleting orphaned routes and associating routes with applications [story](https://www.pivotaltracker.com/story/show/163156064)
  - we've improved the speed of cf services - it now hits a single endpoint instead of making individual API calls
  [#]## Bug Fixes
  [#]# Other Bug Fixes
  - Updates help text for `cf curl`[story](https://www.pivotaltracker.com/story/show/133394731)
  - Now refresh tokens work properly whilst using `cf curl` with V3 CC API endpoints [story](https://www.pivotaltracker.com/story/show/142716197)
  - Fixes performance degradation for `cf services` [story](https://www.pivotaltracker.com/story/show/163296235)
  - `cf delete-service` requires that you are targeting a space [story](https://www.pivotaltracker.com/n/projects/2105761/stories/162635933)
  - `cf enable-service access` for a service in an org will succeed if you have already enabled access for that service in that org [story](https://www.pivotaltracker.com/n/projects/2105761/stories/162747373)
  - `rename-service` updated to no longer fail if a plan has been removed from the catalog [story](https://www.pivotaltracker.com/story/show/162550421)
* Thu May  2 2019 thardeck@suse.com
- update to version 6.44.0
  [#]# Enhancements
  - A new flag `--no-plans` added to `cf marketplace` to view the table without the `plans` column [story](https://www.pivotaltracker.com/story/show/164981967)
  [#]# Minor Enhancements
  - `cf help ` now displays a more prominent `TIP` so that users can discover `cf help -a`
  - Roles for the `set-org-role` and `set-space-role` commands are case insensitive [story](https://www.pivotaltracker.com/story/show/163495325)
  - Piping a multi-line file to `cf login` now works as expected [story](https://www.pivotaltracker.com/story/show/164256604)
  - Updated the help text for `cf delete-orphaned-routes` to clarify that the command is spaced-scoped [story](https://www.pivotaltracker.com/story/show/164657893)
  [#]# Bug Fixes
  - Fixes a bug for `cf update-buildpack` for assigning stacks [story](https://www.pivotaltracker.com/story/show/164998479)
  - Fixes an issue with `cf-bind-route-service` whereby if a user does not have a `org` or `space` targeted, instead of returning a useful error, the CLI would attempt to `GET` the `private_domains` endpoint [story](https://www.pivotaltracker.com/story/show/164157632)
  - `v3-apply-manifest` no works for defining environment variables in a multi-app manifest [story](https://www.pivotaltracker.com/story/show/164998227)
  - Now the CLI checks the expiration time of an access token and refreshes it automatically before making a call the CF API [story](https://github.com/cloudfoundry/cli/pull/1594)
  - `cf marketplace` no longer lists disabled plans [story](https://www.pivotaltracker.com/story/show/165674475)
* Thu Feb 21 2019 thardeck@suse.com
- update to version 6.43.0
  [#]## Enhancements
  - `cf curl` supports a new `--fail` flag (primarily for scripting purposes) which returns exit code `22` for server errors [story](https://www.pivotaltracker.com/story/show/130060949)
  - Improves `cf delete-orphaned-routes` such that it uses a different endpoint, reducing the chance of a race condition when two users are simultaneously deleting orphaned routes and associating routes with applications [story](https://www.pivotaltracker.com/story/show/163156064)
  - we've improved the speed of cf services - it now hits a single endpoint instead of making individual API calls
  [#]## Bug Fixes
  [#]### Security
  - Fixes issue with running cf login in verbose mode whereby passwords which contains regex were not completely redacted
  - Fixes issue whilst running commands in verbose mode refresh tokens were not completely redacted
  [#]## Other Bug Fixes
  - Updates help text for cf curlstory
  - Now refresh tokens work properly whilst using cf curl with V3 CC API endpoints story
  - Fixes performance degradation for cf services story
  - cf delete-service requires that you are targeting a space story
  - cf enable-service access for a service in an org will succeed if you have already enabled access for that service in that org story
* Thu Jan 17 2019 thardeck@suse.com
- update to version 6.42.0
  [#]## Minor Enhancements
  - updated `cf restage` help text and the first line in the command's output to indicate that using this command will cause app downtime [story](https://www.pivotaltracker.com/story/show/151841382)
  - updated the `cf bind-route-service` help text to clarify usage instructions [story](https://www.pivotaltracker.com/story/show/150111078)
  - improved an error message for `cf create-service-boker` to be more helpful when the CC API returns a `502` due to an invalid service broker catalog
  - upgraded to Golang 1.11.4 [story](https://www.pivotaltracker.com/story/show/162745359)
  - added a short name `ue` for `cf unset-env` [story](https://www.pivotaltracker.com/story/show/161632713)
  - updated `cf marketplace` command to include a new `broker` column to prepare for a upcoming services-related feature which will allow services to have the same name as long as they are associated with different service brokers [story](https://www.pivotaltracker.com/story/show/162699756)
  [#]## Bugs
  - fix for `cf enable-service-access -p plan` whereby when we refactored the code in CLI `v6.41.0` it created service plan visibilities as part of a subsequent run of the command (the unrefactored code skipped creating the service plan visibilities); now the command will skip creating service plan visibilities as it did prior to the refactor [story](https://www.pivotaltracker.com/story/show/162747373)
  - updated the `cf rename-buildpack` help text which was missing reference to the `-s` stack flag [story](https://www.pivotaltracker.com/story/show/162428661)
  - updated help text for when users use `brew search cloudfoundry-cli` [story](https://www.pivotaltracker.com/story/show/161770940)
  - now when you run `cf service service-instance` for a route service, the route service url appears in the key value table [story](https://www.pivotaltracker.com/story/show/162498211)
* Mon Dec  3 2018 thardeck@suse.com
- update to version 6.41.0
  [#]## Enhancements
  - updated `cf --help` to include the `delete` command [story](https://www.pivotaltracker.com/story/show/161556511)
* Tue Nov 13 2018 okurz@suse.com
- Require specific version for self-test; disable debug packages in test to prevent error about missing files
* Mon Nov 12 2018 thardeck@suse.com
- update to version 6.40.1
  [#]## Bug Fixes
  - Updates the minimum version for the buildpacks-stacks association feature. In [CLI v6.39.0](https://github.com/cloudfoundry/cli/releases/tag/v6.39.0), when the feature was released, we incorrectly set the minimum to cc api version as`2.114`. The minimum cc api version is now correctly set to [`2.112`](https://github.com/cloudfoundry/capi-release/releases/tag/1.58.0).  [story](https://www.pivotaltracker.com/story/show/161464797)
  - Fixes a bug with inspecting a service instance `cf service service-instance`, now the `documentation` url displays correctly for services which populate that field [story](https://www.pivotaltracker.com/story/show/161251875)
* Mon Oct  8 2018 thardeck@suse.com
- update to version 6.40.0
  [#]## Bug Fixes
  - Fix bug where trailing slash on cf api would break listing commands for older CC APIs story. For older versions of CC API, if the API URL had a trailing slash, some requests would fail with an "Unknown request" error. These requests are now handled properly.
* Thu Sep 20 2018 thardeck@suse.com
- update to version 6.39.1
* Tue Sep 11 2018 thardeck@suse.com
- update to version 6.39.0
  [#]## Enhancements
  - for users on cc api 3.27, cf start is enhanced to display the new cf app v3 output. For users on cc api 3.27 or lower, users will see the same v2 output. Note that if you use v3 commands to create and start your app, if you subsequently use cf stop and cf start, the routes property in cf app will not populate even though the route exists story
  - for users on cc api 3.27, cf restart is enhanced to display the new cf app v3 output. For users on cc api 3.27 or lower, users will see the same v2 output. story
  - for users on cc api 3.27, cf restage is enhanced to display the new cf app v3 output. For users on cc api 3.27 or lower, users will see the same v2 output. story
  - improved help text for -d domains for cf push to include examples of usage story
  - cf v3-scale displays additional app information story
  - if you've created an internal domain, and it is the first domain in cc, the CLI will now ignore the internal domain and instead choose the next non-internal domain when you push an app story
  [#]## Bug Fixes
  - Fix for users on macOS attempting to brew install cf-cli the CF CLI using the unreleased master branch of Homebrew story
  - Fixes an issue whereby, due to a recent cc api change, when you execute cf push and watch the cf app command, the app display returned a 400 error story
  - Fixes a bug whereby if you logged in using client credentials, cf auth user pass --client credentials you were unable to create an org; now create-org will assign the role to the user id specified in your manifest story
  - fixes an issue introduced when we refactored cf start and as part of that work, we stopped blocking on the initial connection with the logging backend; now the CLI blocks until the NOAA connection is made, or the default dial timeout of five seconds is reached story
* Fri Aug 17 2018 okurz@suse.com
- Change package self-test to _multibuild single-spec file approach for easier
  handling of package submissions
* Wed Aug  8 2018 thardeck@suse.com
- update to version 6.38.0
  [#]## Enhancements
  - v3-ssh process type now defaults to web story
  - Support added for setting tags for user provided service instances story
  - Now a warning appears if you attempt to use deprecated properties and variable substitution story
  - Updated usage so now you can rename the cf binary use it with every command story
  - cf events now displays the Diego cell_id and instance guid in crash events story
  - Includes cf service service-instance table display improvements wherein the service instance information is now grouped separately from the binding information story
  - cf service service-instance table display information for user provided services changed: status has been added to the table story
  [#]## Bug Fixes
  - the CLI now properly handles escaped commas in the X-Cf-Warnings header
* Sat Jul 14 2018 okurz@suse.com
- Add package installation and post-install self-test
* Tue May 29 2018 thardeck@suse.com
- update to version 6.37.0
  [#]## Enhancements
  - The api/cloudcontroller/ccv2 package has been updated with more functions #1343
  - Now a warning appears if you are using a API version older than 2.69.0, which is no longer officially supported
  - Now the CLI reads the username and password from the environment variables #1358
  [#]## Bug Fixes
  - Fixes bug whereby X-Cf-Warnings were not being unescaped when displayed to user #1361
  - When using CF_TRACE=1, passwords are now sanitized #1375 and tracker
* Thu May 17 2018 thardeck@suse.com
- update to version 6.36.2
* Thu Apr  5 2018 thardeck@suse.com
- update to version 6.36.1
* Tue Apr  3 2018 thardeck@suse.com
- update to version 6.36.0
  [#]## Bug Fixes
  - int64 support for cf/flags library, #1333
  - Debian package, #1336
  - Web action flag not working on CLI 0.6.5, #1337
  - When a cf push upload fails/Consul is down, a panic occurs, #1340 and #1351
* Fri Mar 16 2018 thardeck@suse.com
- update to version 6.35.2
  [#]## Bug Fixes
  - Providing a clearer services authorization warning message when a service has been disabled for the organization, fixing #1344
* Thu Mar 15 2018 thardeck@suse.com
- update to version 6.35.1
* Fri Mar  9 2018 thardeck@suse.com
- update to version 6.35.0
* Tue Feb  6 2018 thardeck@suse.com
- add rpmlintrc file to spec
- remove source url to prevent issues with the Concourse
  github-release resource
* Tue Feb  6 2018 aosthof@suse.de
- Include in SLE 15 CAP Module (fate#324528)
* Thu Jan 18 2018 thardeck@suse.com
- update to version 6.34.1
* Wed Jan 10 2018 thardeck@suse.com
- update to version 6.34.0
* Fri Dec 15 2017 thardeck@suse.com
- update to version 6.33.1
* Mon Dec 11 2017 thardeck@suse.com
- remove obsolete go-bindata statement (fixes segmentation fault)
- add simple check to verify that cf does not segfault
* Tue Nov 21 2017 thardeck@suse.com
- update to version 6.33.0
* Thu Oct 12 2017 thardeck@suse.com
- update to version 6.32.0
* Thu Oct 12 2017 thardeck@suse.com
- run go-bindata to create the in newer tarballs  missing resource file
  (borrowed from bin/generate-language-resources to work without internet)
* Fri Sep 15 2017 thardeck@suse.com
- update to version 6.31.0
* Fri Sep  1 2017 thardeck@suse.com
- update to version 6.30.0
* Fri Aug 25 2017 thardeck@suse.com
- update to version 6.29.2
* Thu Aug 17 2017 thardeck@suse.com
- update to version 6.29.1
* Tue Jul 25 2017 thardeck@suse.com
- update to version 6.29.0
* Thu Jun 29 2017 thardeck@suse.com
- update to version 6.28.0
* Thu Jun 29 2017 thardeck@suse.com
- CHANGELOG.md was removed updstream
* Fri Jun  9 2017 thardeck@suse.com
- update to version 6.27.0
* Fri Jun  9 2017 thardeck@suse.com
- require go >= 1.8.3 during build time which is necessary from version 6.27.0 on
* Fri Apr  7 2017 thardeck@suse.com
- update to version 6.26.0
* Thu Apr  6 2017 thardeck@suse.com
- adapt spec file to handle tarballs downloaded by concourse
* Wed Mar 22 2017 thardeck@suse.com
- revert some spec changes to fix Tumbleweed building
* Tue Mar 21 2017 thardeck@suse.com
- clean up spec file
* Tue Mar 21 2017 thardeck@suse.com
- install and enable bash completion
* Fri Mar  3 2017 thardeck@suse.com
- update to version 6.25.0
- adapt spec to go packaging changes
- provide full url as source path
* Sat Feb 11 2017 svollath@suse.de
- update to version 6.24.0
* Tue Jan 17 2017 thardeck@suse.com
- update to version 6.23.1
- clean up doc file packaging
- remove disabled checks and macros
* Tue Dec 20 2016 svollath@suse.de
- renamed source tarball to real name (v6.22.2.tar.gz)
* Mon Dec  5 2016 svollath@suse.de
- change cf version string with patch instead of script in specfile
* Fri Oct 28 2016 svollath@suse.de
- update to version 6.22.2+61ce394
- fix cf command to return correct version string
- replace upstream README.md with local README
* Wed Oct 26 2016 svollath@suse.de
- initial package for version 6.22.1+6b7af9c
